@@ -1,9 +1,35 @@
+/*
+ * Dropbear - a SSH2 server
+ * 
+ * Copyright (c) 2002,2003 Matt Johnston
+ * All rights reserved.
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE. */
+
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
 
 #include "options.h"
 #include "session.h"
@@ -18,25 +44,28 @@
 #include "channel.h"
 
 
-static void session_init(int sock, runopts *opts, int childpipe);
+static void session_init(int sock, runopts *opts, int childpipe,
+		struct sockaddr *remote_addr);
 static void session_identification();
 static void checktimeouts();
 
 struct sshsession ses;
 
-void child_session(int sock, runopts *opts, int childpipe) {
+void child_session(int sock, runopts *opts, int childpipe,
+		struct sockaddr *remote_addr) {
 
 	fd_set readfd, writefd;
 	struct timeval timeout;
 	int val;
 	
-	initrandom();
 	crypto_init();
-	session_init(sock, opts, childpipe);
+	session_init(sock, opts, childpipe, remote_addr);
 
 	/* exchange identification, version etc */
 	session_identification();
 
+	seedrandom();
+
 	/* start off with key exchange */
 	send_msg_kexinit();
 
@@ -154,11 +183,14 @@ void session_cleanup() {
 #endif
 
 /* called only at the start of a session, set up initial state */
-static void session_init(int sock, runopts *opts, int childpipe) {
+static void session_init(int sock, runopts *opts, int childpipe,
+		struct sockaddr *remote_addr) {
 
 	struct timeval tv;
 	TRACE(("enter session_init"));
 
+	ses.remote_addr = remote_addr;
+
 	ses.sock = sock;
 	ses.maxfd = sock;
 
