@@ -1,3 +1,27 @@
+/*
+ * Dropbear - a SSH2 server
+ * 
+ * Copyright (c) 2002,2003 Matt Johnston
+ * All rights reserved.
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE. */
+
 #ifndef _SESSION_H_
 #define _SESSION_H_
 
@@ -15,7 +39,8 @@
 #include "queue.h"
 #include "runopts.h"
 
-void child_session(int sock, runopts *opts, int childpipe);
+void child_session(int sock, runopts *opts, int childpipe,
+		struct sockaddr *remote_addr);
 #ifdef DOCLEANUP
 void session_cleanup();
 #endif
@@ -50,6 +75,9 @@ struct sshsession {
 	int sock;
 	int childpipe; /* kept open until we successfully authenticate */
 	long connecttime; /* time of initial connection */
+
+	struct sockaddr *remote_addr;
+
 	unsigned int maxfd; /* the maximum file descriptor to check with select() */
 	unsigned char *remoteident;
 
@@ -61,8 +89,6 @@ struct sshsession {
 
 	unsigned char expecting; /* byte indicating what packet we expect next, 
 								or 0x00 for any */
-
-
 	
 	/* unencrypted write payload */
 	buffer *writepayload; /* this will actually refer to within clearwritebuf */
